@@ -36,10 +36,10 @@ from .models import Models
 from .twofactor_auth import TwoFactorAuth
 
 
-__version__ = '11.1.1'
+__version__ = '11.2.0'
 
 
-class Balena(object):
+class Balena:
     """
     This class implements all functions supported by the python SDK.
     Attributes:
